@@ -210,14 +210,16 @@ class Appliance():
         if program is not None:
             program_key = program.key
 
-        if program_key is None and self.selected_program is not None:
-            program_key = self.selected_program.key
-        else:
-            _LOGGER.error('Either "program" or "key" must be specified')
-            return False
+        if not program_key:
+            if self.selected_program:
+                program_key = self.selected_program.key
+            else:
+                _LOGGER.error('Either "program" or "key" must be specified')
+                return False
 
         if not self.available_programs or program_key not in self.available_programs:
             _LOGGER.warning("The selected program in not one of the available programs (not supported by the API)")
+            raise HomeConnectError("The specified program in not one of the available programs (not supported by the API)")
             return False
 
         if options is None and self.selected_program and self.available_programs:
@@ -468,7 +470,7 @@ class Appliance():
             _LOGGER.debug("Starting to load appliance data for %s (%s)", self.name, self.haId)
             if include_static_data:
                 available_programs = await self._async_fetch_programs('available')
-                if available_programs and (not self.available_programs or len(available_programs)<2):
+                if available_programs and (not self.available_programs or len(self.available_programs)<2):
                     # Only update the available programs if we got new data
                     self.available_programs = available_programs
 
